@@ -948,15 +948,7 @@ exchange_mapi_cal_util_mapi_props_to_comp (ExchangeMapiConnection *conn, mapi_id
 		if (b && *b) {
 			stream = exchange_mapi_util_find_stream (streams, PidLidAppointmentRecur);
 			if (stream) {
-				icaltimezone *recur_zone;
-				const gchar *recur_tz_location;
-
-				recur_tz_location = exchange_mapi_util_find_array_namedid (properties, conn, fid, PidLidTimeZoneDescription);
-				if (recur_tz_location)
-					recur_tz_location = exchange_mapi_cal_tz_util_get_ical_equivalent (recur_tz_location);
-				recur_zone = recur_tz_location ? icaltimezone_get_builtin_timezone (recur_tz_location) : (icaltimezone *) default_zone;
-
-				exchange_mapi_cal_util_bin_to_rrule (stream->value, comp, detached_components, recur_zone);
+				exchange_mapi_cal_util_bin_to_rrule (stream->value, comp, detached_components);
 			}
 		}
 
@@ -1235,7 +1227,8 @@ appt_build_name_id (ExchangeMapiConnection *conn, mapi_id_t fid, TALLOC_CTX *mem
 		{ PidLidIsException, 0 },
 		{ PidLidCleanGlobalObjectId, 0 },
 		{ PidLidAppointmentMessageClass, 0 },
-		{ PidLidMeetingType, 0 }
+		{ PidLidMeetingType, 0 },
+		{ PidLidTimeZone, 0 }
 	};
 
 	if (!props)
@@ -1647,6 +1640,21 @@ exchange_mapi_cal_utils_write_props_cb (ExchangeMapiConnection *conn, mapi_id_t
 			set_named_value (PidLidAppointmentTimeZoneDefinitionEndDisplay, &end_tz);
 		}
 
+		/* Recurrences also need to have this rather arbitrary index set
+		   to properly determine SDT/DST and appear in OWA (Bug #629057). */
+		if (e_cal_component_has_recurrences (comp)) {
+			uint64_t pltz;
+			icaltimezone *ictz;
+			const gchar *zone_location = dtstart_tz_location;
+
+			if (!zone_location)
+				zone_location = get_tzid_location ("*default-zone*", cbdata);
+
+			ictz = icaltimezone_get_builtin_timezone (zone_location);
+			pltz = exchange_mapi_cal_util_mapi_tz_pidlidtimezone (ictz);
+			set_named_value (PidLidTimeZone, &pltz);
+		}
+
 		/* Duration */
 		flag32 = icaldurationtype_as_int (icaltime_subtract (dtend, dtstart));
 		flag32 /= MINUTES_IN_HOUR;
